Reader

Struct Reader 

pub struct Reader<R: Read> { /* private fields */ }

Implementations

Source

impl<R: Read> Reader<R>

pub fn from_reader(rdr: R) -> Reader<R>

Creates a new buffered reader from any struct that implements the Read trait.

Source

impl Reader<File>

pub fn from_path<P: AsRef<Path>>(path: P) -> Result<Reader<File>, Error>

Creates a new buffered reader from a file path.

Source

impl<'a, R: Read> Reader<R>

pub fn deserialize<'de, D: DeserializeOwned>( &mut self, ) -> DesRecordIter<'_, D, R>

Returns an iterator that will continuously decode records from the underlying reader.

pub fn read_record(&mut self, buf: &mut Vec<u8>) -> Option<Result<(), Error>>